pub enum GradientTransformError {
InvalidScalar,
InvalidDType,
ParameterMismatch(ParamId),
QuantizedGradient(ParamId),
UnknownParameters,
}Expand description
Invalid gradient metadata or an explicit scaling argument.
Variants
InvalidScalar
The multiplier/divisor is not finite or cannot be represented in the work dtype.
InvalidDType
The requested arithmetic dtype is not F32 or F64.
ParameterMismatch(ParamId)
A gradient does not have its parameter’s geometry or device.
QuantizedGradient(ParamId)
A gradient is quantized; arithmetic must not silently dequantize it.
UnknownParameters
At least one registered gradient is not owned by the supplied module.