pub enum GradientClipping {
Value(f32),
Norm(f32),
}Expand description
Gradient Clipping provides a way to mitigate exploding gradients by clipping every component of the gradient by value or by norm during backpropagation.
Variants
Implementations