pub struct CenteredState<B: Backend, const D: usize> {
pub grad_avg: Option<Tensor<B, D>>,
pub avg: Tensor<B, D>,
}Expand description
CenteredState is to store and pass optimizer step params.
Fields
grad_avg: Option<Tensor<B, D>>The averaged gradient to calculate the centered gradient, if available.
avg: Tensor<B, D>The current average value.
Implementations
Sourceimpl<B: Backend, const D: usize> CenteredState<B, D>
impl<B: Backend, const D: usize> CenteredState<B, D>