Module training

Module training 

Available on crate feature std only.
Combined model, optimizer, scheduler and accumulated-gradient records.

Structs

RestoredTraining
Components restored together, including pending gradients and caller state.
TrainingRecord
One record containing the trainable state and a caller-defined continuation record.